@@ -23,9 +23,13 @@ public class Values extends ArrayList<Object> {
     }
 
     public Values(Object... vals) {
-        super(vals.length);
-        for (Object o : vals) {
-            add(o);
+        super(vals != null ? vals.length : 1);
+        if (vals != null) {
+            for (Object o : vals) {
+                add(o);
+            }
+        } else {
+            add(null);
         }
     }
 }
