@@ -761,8 +761,8 @@ public class TestResourceAwareScheduler {
             rs.schedule(topologies, cluster);
             assertTrue(cluster.needsSchedulingRas(topology2));
             String status = cluster.getStatusMap().get(topology2.getId());
-            assert status.startsWith("Not enough resources to schedule") : status;
-            //assert status.endsWith("5 executors not scheduled") : status;
+            String expectedStatusPrefix = "Not enough resources to schedule";
+            assertTrue(status.startsWith(expectedStatusPrefix), "Expected status to start with \"" + expectedStatusPrefix + "\" but status is: " + status);
             assertEquals(5, cluster.getUnassignedExecutors(topology2).size());
         } finally {
             rs.cleanup();
@@ -1136,7 +1136,7 @@ public class TestResourceAwareScheduler {
 
     private long getMedianValue(List<Long> values) {
         final int numValues = values.size();
-        assert(numValues % 2 == 1);     // number of values must be odd to compute median as below
+        assertEquals(1, (numValues % 2), "Expecting odd number of values to compute median, got " + numValues);
         List<Long> sortedValues = new ArrayList<>();
         sortedValues.addAll(values);
         Collections.sort(sortedValues);
